@@ -1,8 +1,7 @@
+# SPDX-License-Identifier: GPL-2.0-or-later
 # This file is part of Scapy
-# See http://www.secdev.org/projects/scapy for more information
-# Copyright (C) Philippe Biondi <phil@secdev.org>
-# Copyright (C) Gabriel Potter <gabriel@potter.fr>
-# This program is published under a GPLv2 license
+# See https://scapy.net/ for more information
+# Copyright (C) Gabriel Potter <gabriel[]potter[]fr>
 
 # flake8: noqa E266
 # (We keep comment boxes, it's then one-line comments)
@@ -13,13 +12,26 @@ C API calls to Windows DLLs
 
 import ctypes
 import ctypes.wintypes
-from ctypes import Structure, POINTER, byref, create_string_buffer, WINFUNCTYPE
-
+from ctypes import (
+    POINTER,
+    Structure,
+    WINFUNCTYPE,
+    byref,
+    create_string_buffer,
+)
 from scapy.config import conf
 from scapy.consts import WINDOWS_XP
 
+# Typing imports
+from scapy.compat import (
+    AddressFamily,
+    Any,
+    Dict,
+    List,
+    Optional,
+)
+
 ANY_SIZE = 65500  # FIXME quite inefficient :/
-AF_UNSPEC = 0
 NO_ERROR = 0x0
 
 CHAR = ctypes.c_char
@@ -47,6 +59,7 @@ USHORT = ctypes.c_ushort
 
 
 def _resolve_list(list_obj):
+    # type: (Any) -> List[Dict[str, Any]]
     current = list_obj
     _list = []
     while current and hasattr(current, "contents"):
@@ -56,7 +69,8 @@ def _resolve_list(list_obj):
 
 
 def _struct_to_dict(struct_obj):
-    results = {}
+    # type: (Any) -> Dict[str, Any]
+    results = {}  # type: Dict[str, Any]
     for fname, ctype in struct_obj.__class__._fields_:
         val = getattr(struct_obj, fname)
         if fname == "next":
@@ -83,8 +97,11 @@ _winapi_SetConsoleTitle.restype = BOOL
 _winapi_SetConsoleTitle.argtypes = [LPWSTR]
 
 def _windows_title(title=None):
-    """Updates the terminal title with the default one or with `title`
-    if provided."""
+    # type: (Optional[str]) -> None
+    """
+    Updates the terminal title with the default one or with `title`
+    if provided.
+    """
     if conf.interactive:
         _winapi_SetConsoleTitle(title or "Scapy v{}".format(conf.version))
 
@@ -119,6 +136,7 @@ QueryServiceStatus.restype = BOOL
 QueryServiceStatus.argtypes = [SC_HANDLE, POINTER(SERVICE_STATUS)]
 
 def get_service_status(service):
+    # type: (str) -> Dict[str, int]
     """Returns content of QueryServiceStatus for a service"""
     SERVICE_QUERY_STATUS = 0x0004
     schSCManager = OpenSCManagerW(
@@ -221,11 +239,12 @@ _GetIcmpStatistics = WINFUNCTYPE(ULONG, PMIB_ICMP)(
 
 
 def GetIcmpStatistics():
+    # type: () -> Dict[str, Dict[str, Dict[str, int]]]
     """Return all Windows ICMP stats from iphlpapi"""
     statistics = MIB_ICMP()
     _GetIcmpStatistics(byref(statistics))
     results = _struct_to_dict(statistics)
-    del(statistics)
+    del statistics
     return results
 
 ##############################
@@ -432,7 +451,8 @@ _GetAdaptersAddresses = WINFUNCTYPE(ULONG, ULONG, ULONG,
                                         ('GetAdaptersAddresses', iphlpapi))
 
 
-def GetAdaptersAddresses(AF=AF_UNSPEC):
+def GetAdaptersAddresses(AF=AddressFamily.AF_UNSPEC):
+    # type: (int) -> List[Dict[str, Any]]
     """Return all Windows Adapters addresses from iphlpapi"""
     # We get the size first
     size = ULONG()
@@ -453,7 +473,7 @@ def GetAdaptersAddresses(AF=AF_UNSPEC):
     if res != NO_ERROR:
         raise RuntimeError("Error retrieving table (%d)" % res)
     results = _resolve_list(AdapterAddresses)
-    del(AdapterAddresses)
+    del AdapterAddresses
     return results
 
 ##############################
@@ -495,6 +515,7 @@ _GetIpForwardTable = WINFUNCTYPE(DWORD,
 
 
 def GetIpForwardTable():
+    # type: () -> List[Dict[str, Any]]
     """Return all Windows routes (IPv4 only) from iphlpapi"""
     # We get the size first
     size = ULONG()
@@ -512,7 +533,7 @@ def GetIpForwardTable():
     results = []
     for i in range(pIpForwardTable.contents.NumEntries):
         results.append(_struct_to_dict(pIpForwardTable.contents.Table[i]))
-    del(pIpForwardTable)
+    del pIpForwardTable
     return results
 
 ### V2 ###
@@ -571,7 +592,8 @@ if not WINDOWS_XP:
     )
 
 
-def GetIpForwardTable2(AF=AF_UNSPEC):
+def GetIpForwardTable2(AF=AddressFamily.AF_UNSPEC):
+    # type: (AddressFamily) -> List[Dict[str, Any]]
     """Return all Windows routes (IPv4/IPv6) from iphlpapi"""
     if WINDOWS_XP:
         raise OSError("Not available on Windows XP !")
